/**
 * Rule: no-http-success-error
 * Ensures that promises dont use success, error callback functions.
 */

module.exports = {

    meta: {
        docs: {
            description: "Dont allow HTTP service with success and error functions",
            category: "Possible Errors",
            recommended: true
        },
        schema: [] // no options
    },

  create: function (context) {

    function checkPromiseFunction(node) {

        if (node.expression.type === 'CallExpression' &&
            node.expression.callee.type === 'MemberExpression' &&
            node.expression.callee.property.name === 'then'
        ) {
            return
        }

        if (node.expression.type === 'CallExpression' &&
            node.expression.callee.type === 'MemberExpression' &&
            (node.expression.callee.property.name === 'success' || node.expression.callee.property.name === 'error' )
        ) {
            context.report(node, 'Dont use success() and error() in HTTP service. Use then() function instead.')
        }

    }

    return {
        "ExpressionStatement": checkPromiseFunction
    };
  }
};
